repetition/enum_shifted.hpp

The repetition/enum_shifted.hpp header defines a construct that produces a comma-separated, shifted list.

#### Usage

#include <boost/preprocessor/repetition/enum_shifted.hpp>

#### Contents

- BOOST_PP_ENUM_SHIFTED
- BOOST_PP_ENUM_SHIFTED_z

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)